@@ -3,7 +3,7 @@ import pytest
 from js_example import app
 
 
-@pytest.fixture(name='app')
+@pytest.fixture(name="app")
 def fixture_app():
     app.testing = True
     yield app
