@@ -1,6 +1,7 @@
 import sqlite3
 
 import pytest
+
 from flaskr.db import get_db
 
 
@@ -10,9 +11,9 @@ def test_get_close_db(app):
         assert db is get_db()
 
     with pytest.raises(sqlite3.ProgrammingError) as e:
-        db.execute('SELECT 1')
+        db.execute("SELECT 1")
 
-    assert 'closed' in str(e)
+    assert "closed" in str(e.value)
 
 
 def test_init_db_command(runner, monkeypatch):
@@ -22,7 +23,7 @@ def test_init_db_command(runner, monkeypatch):
     def fake_init_db():
         Recorder.called = True
 
-    monkeypatch.setattr('flaskr.db.init_db', fake_init_db)
-    result = runner.invoke(args=['init-db'])
-    assert 'Initialized' in result.output
+    monkeypatch.setattr("flaskr.db.init_db", fake_init_db)
+    result = runner.invoke(args=["init-db"])
+    assert "Initialized" in result.output
     assert Recorder.called
